@@ -16,10 +16,29 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: calendar.pl,v 1.20 2004/06/29 16:42:09 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: calendar.pl,v 1.29 2004/10/12 22:09:12 as Exp $</p>';
 
 use vars qw($CalendarOnEveryPage $CalendarUseCal);
 
+$DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /div\.month/; # mod_perl?
+div.month { float:right; margin:0; padding-left:1ex; padding-right:1ex; }
+div.footer { clear:both; }
+div.year div.month { float:left; }
+div.month pre { margin:0; padding:0; background-color:#ffe; }
+div.month a { text-decoration:none; color:inherit; }
+div.month span.title a { background-color:inherit; }
+div.month a.exact { background-color:#eef; }
+div.month a.collection { background-color:#ccf; }
+div.month a.today { background-color:#fcc; }
+div.month a[class~="today"][class~="exact"] { background-color:#fcf; }
+div.month a[class~="today"][class~="collection"] { background-color:#faf; }
+@media print {
+  div.month { display: none; }
+  div.year div.month { display: block; }
+  div.year div.month a { display: inline; }
+}
+EOT
+
 $CalendarOnEveryPage = 1;
 $CalendarUseCal = 1;
 
@@ -29,19 +48,20 @@ $CalendarUseCal = 1;
 sub NewCalendarGetHeader {
   my $header = OldCalendarGetHeader(@_);
   return $header unless $CalendarOnEveryPage;
+  my $action = GetParam('action', 'browse');
+  return $header if grep(/^$action$/, ('calendar', 'edit'));
   my $cal = Cal();
   $header =~ s/<div class="header">/$cal<div class="header">/;
   return $header;
 }
 
 sub Cal {
-  my ($year, $mon, $mday, $unlink_year) = @_; # example: 2004, 12.
-  if (not $mon) {
-    my ($sec, $min, $hour);
-    ($sec, $min, $hour, $mday, $mon, $year) = localtime($Now);
-    $mon += 1;
-    $year += 1900;
-  }
+  my ($year, $mon, $unlink_year) = @_; # example: 2004, 12
+  my ($sec_now, $min_now, $hour_now, $mday_now, $mon_now, $year_now) = localtime($Now);
+  $mon_now += 1;
+  $year_now += 1900;
+  $year = $year_now unless $year;
+  $mon = $mon_now unless $mon;
   my @pages = AllPagesList();
   my $cal = '';
   if ($CalendarUseCal) {
@@ -53,11 +73,12 @@ sub Cal {
 	 $cal = Date::Pcalc::Calendar( $year, $mon ); } unless $cal;
   return T('Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.')
     unless $cal;
-  $cal =~ s|\b( ?\d?\d)\b|{
+  $cal =~ s|\b([A-Z][a-z])\b|{ T($1); }|ge;
+  $cal =~ s|\b( ?[ 0-9]?[0-9])\b|{
     my $day = $1;
     my $date = sprintf("%d-%02d-%02d", $year, $mon, $day);
-    my $class;
-    $class = ' today' if $day == $mday;
+    my $class = '';
+    $class .= ' today' if $day == $mday_now and $mon == $mon_now and $year == $year_now;
     my @matches = grep(/^$date/, @pages);
     my $link;
     if (@matches == 0) { # not using GetEditLink because of $class
@@ -71,6 +92,7 @@ sub Cal {
   }|ge;
   $cal =~ s|(\w+) (\d\d\d\d)|{
     my ($month_text, $year_text) = ($1, $2);
+    $month_text = T($month_text);
     my $date = sprintf("%d-%02d", $year, $mon);
     if ($unlink_year) {
       $q->span({-class=>'title'}, ScriptLink('action=collect;match=' . $date,
@@ -147,7 +169,7 @@ sub PrintYearCalendar {
 	      ' | ',
 	      ScriptLink('action=calendar;year=' . ($year+1), T('Next')));
   for $mon ((1..12)) {
-    print Cal($year, $mon, undef, 1);
+    print Cal($year, $mon, 1);
   }
   print '</div>';
 }
