@@ -38,18 +38,8 @@ RSS parsing failed for %s
 
  . . . . 
 
-Click to create this page
+Click to edit this page
 
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
-
-http://www.amazon.com/exec/obidos/ISBN=%s
-
-alternate
-alternativo
-http://www.pricescan.com/books/BookDetail.asp?isbn=%s
-
-search
-buscar
 Invalid action parameter %s
 Parámetro de acción %s inválido
 Invalid URL.
@@ -102,14 +92,14 @@ Include minor changes
 %s días
 List later changes
 
+Filters
+
 Username:
 
 Host:
 
 Language:
 
-Filters
-
 Go!
 Iniciar
 (minor)
@@ -320,6 +310,8 @@ This operation is restricted to site editors only...
 Esta operación está restringida para su uso por editores únicamente...
 This operation is restricted to administrators only...
 Esta operación está restringida para su uso por administradores únicamente...
+Rule "%1" matched "%2" on this page.
+
 Index of all pages
 Índice de todas las páginas
 all pages
@@ -440,6 +432,8 @@ Too many connections by %s
 Demasiadas conexiones de %s
 Please do not fetch more than %1 pages in %2 seconds.
 
+Check whether the web server can create the directory %s and whether it can create files in it.
+
 Recent Visitors
 Visitantes Recientes
 Referrers
@@ -472,18 +466,26 @@ Delete page
 
 Rename this page to:
 
+Cannot highlight the language %s.
+
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 
 The match parameter is missing.
 
 Page Collection for %s
 
+Previous
+
+Next
+
 Calendar %s
 
 Footnotes:
 
 image: %s
 
+Index
+
 Languages:
 
 Show!
@@ -508,8 +510,14 @@ None
 
 Type
 
+Permalink to "%s"
+
 Portrait
 
+Static Copy
+
+Alternatively, use one of the following templates:
+
 Thread: %s
 
 ID parameter is missing.
@@ -530,6 +538,24 @@ URL:
 
 Name:
 
+Failed to remove %s
+
+The translation is up to date.
+
+The translation is outdated.
+
+The page does not exist.
+
+http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
+
+http://www.amazon.com/exec/obidos/ISBN=%s
+
+alternate
+alternativo
+http://www.pricescan.com/books/BookDetail.asp?isbn=%s
+
+search
+buscar
 Blog
 
 END_OF_TRANSLATION
